==> pollen-votecounting-api-1.5-sources.jar: org/chorem/pollen/votecounting/model/GroupOfVoterBuilder.java <==
package org.chorem.pollen.votecounting.model;

/*
 * #%L
 * Pollen :: VoteCounting Api
 * $Id: GroupOfVoterBuilder.java 3700 2012-09-23 13:09:29Z tchemit $
 * $HeadURL: http://svn.chorem.org/svn/pollen/tags/pollen-1.5/pollen-votecounting-api/src/main/java/org/chorem/pollen/votecounting/model/GroupOfVoterBuilder.java $
 * %%
 * Copyright (C) 2009 - 2012 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */

import com.google.common.base.Preconditions;
import com.google.common.collect.Sets;

import java.util.Set;

/**
 * {@link GroupOfVoter} builder.
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 1.4.6
 */
public class GroupOfVoterBuilder implements VoterBuilder {

    private Set<Voter> voters = Sets.newHashSet();

    private GroupOfVoter groupOfVoter;

    private Voter voter;

    @Override
    public Set<Voter> getVoters() {
        flush();
        return voters;
    }

    @Override
    public GroupOfVoterBuilder newVoter(String voterId, double weight) {
        Preconditions.checkState(groupOfVoter != null, "No groupOfVoter defined, use method newGroupVoter before");
        flushVoter();
        voter = SimpleVoter.newVoter(voterId, weight, null);
        return this;
    }

    @Override
    public GroupOfVoterBuilder addVoteForChoice(String choiceId, Double voteValue) {
        Preconditions.checkState(voter != null, "No voter defined, use method newVoter before this one");
        VoteForChoice voteForChoice = VoteForChoice.newVote(choiceId, voteValue);
        voter.addVoteForChoice(voteForChoice);
        return this;
    }

    public GroupOfVoterBuilder newGroupVoter(String voterId, double weight) {
        flush();
        groupOfVoter = GroupOfVoter.newVoter(voterId, weight, null);
        return this;
    }

    public void flushVoter() {
        if (voter != null) {
            groupOfVoter.addVoter(voter);
            voter = null;
        }
    }

    @Override
    public void flush() {
        if (groupOfVoter != null) {
            flushVoter();
            voters.add(groupOfVoter);
            groupOfVoter = null;
        }
    }

    public GroupOfVoter getRoot() {
        return (GroupOfVoter) getVoters().iterator().next();
    }
}

==> pollen-votecounting-api-1.5.1-sources.jar: org/chorem/pollen/votecounting/model/GroupOfVoterBuilder.java <==
package org.chorem.pollen.votecounting.model;

/*
 * #%L
 * Pollen :: VoteCounting Api
 * $Id: GroupOfVoterBuilder.java 3700 2012-09-23 13:09:29Z tchemit $
 * $HeadURL: http://svn.chorem.org/svn/pollen/tags/pollen-1.5.1/pollen-votecounting-api/src/main/java/org/chorem/pollen/votecounting/model/GroupOfVoterBuilder.java $
 * %%
 * Copyright (C) 2009 - 2012 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */

import com.google.common.base.Preconditions;
import com.google.common.collect.Sets;

import java.util.Set;

/**
 * {@link GroupOfVoter} builder.
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 1.4.6
 */
public class GroupOfVoterBuilder implements VoterBuilder {

    private Set<Voter> voters = Sets.newHashSet();

    private GroupOfVoter groupOfVoter;

    private Voter voter;

    @Override
    public Set<Voter> getVoters() {
        flush();
        return voters;
    }

    @Override
    public GroupOfVoterBuilder newVoter(String voterId, double weight) {
        Preconditions.checkState(groupOfVoter != null, "No groupOfVoter defined, use method newGroupVoter before");
        flushVoter();
        voter = SimpleVoter.newVoter(voterId, weight, null);
        return this;
    }

    @Override
    public GroupOfVoterBuilder addVoteForChoice(String choiceId, Double voteValue) {
        Preconditions.checkState(voter != null, "No voter defined, use method newVoter before this one");
        VoteForChoice voteForChoice = VoteForChoice.newVote(choiceId, voteValue);
        voter.addVoteForChoice(voteForChoice);
        return this;
    }

    public GroupOfVoterBuilder newGroupVoter(String voterId, double weight) {
        flush();
        groupOfVoter = GroupOfVoter.newVoter(voterId, weight, null);
        return this;
    }

    public void flushVoter() {
        if (voter != null) {
            groupOfVoter.addVoter(voter);
            voter = null;
        }
    }

    @Override
    public void flush() {
        if (groupOfVoter != null) {
            flushVoter();
            voters.add(groupOfVoter);
            groupOfVoter = null;
        }
    }

    public GroupOfVoter getRoot() {
        return (GroupOfVoter) getVoters().iterator().next();
    }
}
